import buw.*;

/**
 * example 3a: list view without renderer (using toString)
 * using: VBox, ListView, Separator, Label & TextButton
 */

class Book {
	public var author : String;
	public var title : String;
	public function new(t : String, a : String) {
		author = a;
		title = t;
	}

	//the toString method is required to render list view items (when no renderer is provided)
	public function toString() : String {
		return title + " - " + author;
	}
}

class Example3a {
	public static function main() {
		new Example3a();
	}

	//a list view is a usefull widget to display collections of items; it is strongly typed:
	var booksList : ListView<Book>;

	function new() {
		var rootWindow = new VBox();
		rootWindow.pack(new TextButton(onAddBooksClick, "Add books"));
		Screen.display(rootWindow); //enables vertical scrolling if needed
		rootWindow.pack(new Separator());

		//because a Book has a toString method, no renderer is required; one can provide a callback to tell what to do when an item is clicked:
		booksList = new ListView(onBookClick);
		rootWindow.pack(booksList);
	}

	function onAddBooksClick(w : TextButton) {
		//list views source can be arrays or lists:
		var books : Array<Book> = new Array();
		books.push(new Book("Les misérables", "Victor Hugo"));
		books.push(new Book("20 000 lieues sous les mers", "Jules Verne"));

		//first time the button is clicked, source is set:
		if (booksList.source == null) {
			booksList.source = books;
		} else {
			//then, for demonstration purpose, the same books are added to the existing source:
			for (b in books) {
				booksList.push(b);
			}
		}
	}

	//the callback function is given the clicked item as parameter:
	function onBookClick(b : Book) {
		Sys.println(b.title);
	}
}
