import buw.*;
import openfl.Lib;
import openfl.events.Event;
//~ import openfl.events.KeyboardEvent;
import openfl.display.Sprite;

/**
 * example 6: list view with detail, displaying both (in an horizontal pane) when screen Width > 600px
 * using: HBox, ListView, VBox, Label, TextButton, Paragraph
 */

class Book {
	public var author : String;
	public var title : String;
	public var synopsis : String;
	public function new(t : String, a : String, s : String) {
		author = a;
		title = t;
		synopsis = s;
	}

	public function toString() : String {
		return title;
	}
}

class Example6 extends Sprite {
	static inline var LIST_WIDTH : Float = 0.3; //relative
	static inline var MIN_WIDTH : Int = 600; //pixels

	var booksList : ListView<Book>;
	var bookDetail : VBox;

	var currentScreen : Widget; //booksList xor bookDetail
		//used (displayed) when screen width < 600px

	var hpane : HBox; //the horizontal pane
		//displayed when screen width >= 600px
		//an horizontal box with 2 children: booksList (30%) & booksDetail (70%)

	function new() {
		super();

		//first initialize the widgets:
		var books : Array<Book> = new Array();
		for (i in 0...25) { //to demonstrate scrolling on the list
			books.push(new Book("Ravage", "René Barjavel", "Ravage présente le naufrage d`une société mature, dans laquelle, un jour, " +
				"l`électricité disparaît et plus aucune machine ne peut fonctionner. Les habitants, anéantis par la soudaineté de la " +
				"catastrophe, sombrent dans le chaos, privés d`eau courante, de lumière et de moyens de déplacement."));
			books.push(new Book("Demain les chiens (City)", "Clifford D. Simak", "Sur plusieurs milliers d`années, l`auteur brosse " +
				"un tableau troublant et poétique de l`avenir de l`humanité. Les Hommes perdent petit à petit leur instinct grégaire " +
				"après une série de conflits guerriers et font un retour dans les campagnes, puis laissent la place aux Chiens, qu`ils " +
				"ont réussi à doter de la parole."));
		}
		booksList = new ListView(onBookClick);
		booksList.source = books;

		bookDetail = new VBox(); //empty by default
		hpane = new HBox([new HBoxColumn(LIST_WIDTH), new HBoxColumn(1 - LIST_WIDTH, -1)]); //two columns
		currentScreen = booksList; //default is to display the list

		//listen to resize event to switch between single / dual (horizontal pane) view
		Lib.current.stage.addEventListener(Event.RESIZE, onResize);
		//~ Lib.current.stage.addEventListener(KeyboardEvent.KEY_UP, onKeyUp); //to handle escape key
		draw();
	}

	function onResize(e : Event) {
		draw();
	}

	function draw() {
		hpane.clear(); //remove list and detail view from horizontal box to use full width when < 600px
		if (Lib.current.stage.stageWidth >= MIN_WIDTH) {
			//add list view and detail widget to the horizontal box and display it:
			hpane.pack(booksList);
			hpane.pack(bookDetail);
			Screen.display(hpane);
			Screen.setScrollable(booksList); //only the list view is scrollable

			//draw a separator line between list and detail:
			hpane.graphics.clear();
			hpane.graphics.lineStyle(Widget.borderWidth);
			hpane.graphics.drawRect(Lib.current.stage.stageWidth * LIST_WIDTH, 0, 1, Lib.current.stage.stageHeight);
			hpane.graphics.endFill();
		} else { //display only list or detail:
			Screen.display(currentScreen);
		}
	}

	function onBookClick(b : Book) { //display detail
		bookDetail.clear();
		bookDetail.pack(new Title("Title:"));
		bookDetail.pack(new Label(b.title));
		bookDetail.pack(new Title("Author:"));
		bookDetail.pack(new Label(b.author));
		bookDetail.pack(new Title("Synopsis:"));
		bookDetail.pack(new Paragraph(b.synopsis));
		bookDetail.pack(new TextButton(onBackClick, "Back"));
		currentScreen = bookDetail;
		draw();
	}

	function onBackClick(w : TextButton) { //display list
		bookDetail.clear();
		currentScreen = booksList;
		draw();
		booksList.draw(); //needed if width has changed while displaying detail
	}

	//~ function onKeyUp(e : KeyboardEvent) {
		//~ if (e.keyCode == 27) {
			//~ onBackClick(null);
		//~ }
	//~ }
}
